# Graphical User Interface

Use desktop shortcut or run:

> toolmateai

![gui](https://github.com/user-attachments/assets/dc0df7fe-b1d0-4627-8eb9-b079e635bf0c)

Support user confirmation for code execution:

![user_confirmation](https://github.com/user-attachments/assets/3172aa25-9def-4c41-b896-9d18a2a18334)

Support system tray:

![system_tray](https://github.com/user-attachments/assets/3ec0a415-3ab8-4696-8f32-7662c11e003e)

Select `Edit Configurations` from system tray to change settings:

![setup](https://github.com/user-attachments/assets/731a897f-464b-4b79-b3b8-95de69c5080d)
